@@ -18,7 +18,7 @@ class Player(object):
         self.storage = FileStorage.FileStorage(path = constants._data_path_)
         if hildonize.IS_HILDON_SUPPORTED and not hildonize.IS_FREMANTLE_SUPPORTED:
             import SimpleOSSOPlayer as _SimplePlayer
-            SimpleGStreamer = _SimplePlayer # silence PyFlakes
+            SimplePlayer = _SimplePlayer # silence PyFlakes
         else:
             import SimpleGStreamer as SimplePlayer
         self.player = SimplePlayer.SimplePlayer(self.next_chapter)
@@ -86,7 +86,7 @@ class Player(object):
             self.ui.set_book(bookPath, self.audiobook.get_cover_img())
             self.ui.set_chapters(self.audiobook.chapters)
 
-        chapter_title = self.audiobook.chapters[chapter_num]
+        chapter_title = self.audiobook.chapters[self.audiobook.current_chapter]
         self.set_chapter(chapter_title, True)
 
     def set_chapter(self, chapter, continuing = False):
